var delta_8h =
[
    [ "lzma_options_delta", "structlzma__options__delta.html", "structlzma__options__delta" ],
    [ "LZMA_FILTER_DELTA", "delta_8h.html#a7ced67235ad7a01ae31d32ecf1e634cb", null ],
    [ "LZMA_DELTA_DIST_MIN", "delta_8h.html#a466886d9d01392f61bdf267687a4f96e", null ],
    [ "LZMA_DELTA_DIST_MAX", "delta_8h.html#afdf8a5ce184ddf9f8070de637775da94", null ],
    [ "lzma_delta_type", "delta_8h.html#a04d84d7fa6cefdc219b6e2e96ff36fe1", [
      [ "LZMA_DELTA_TYPE_BYTE", "delta_8h.html#a04d84d7fa6cefdc219b6e2e96ff36fe1afa749f8693200e0e82feef5f99815da4", null ]
    ] ]
];