var block_8h =
[
    [ "lzma_block", "structlzma__block.html", "structlzma__block" ],
    [ "lzma_block_header_size_decode", "block_8h.html#ac025c940683a70f4c7f956bad814fd5f", null ],
    [ "lzma_block_header_size", "block_8h.html#ae9b47abc872d0b02c2da9d3fa5a7dacd", null ],
    [ "lzma_block_header_encode", "block_8h.html#a0eedbd6331d5708ea963260e6f2a92d0", null ],
    [ "lzma_block_header_decode", "block_8h.html#a7f5487c21a7b36a8bd17be36074d43c9", null ],
    [ "lzma_block_compressed_size", "block_8h.html#a6c3e102d76db06a07126a569abc6e2bc", null ],
    [ "lzma_block_unpadded_size", "block_8h.html#a412d5605280fa29befae1b89e344bf30", null ],
    [ "lzma_block_total_size", "block_8h.html#a694424f9dfdd5151e01debac1c501fa9", null ],
    [ "lzma_block_encoder", "block_8h.html#a2218a49025a0b44f9a6f9d6d24359359", null ],
    [ "lzma_block_decoder", "block_8h.html#aa92c73b2a228efe921fa2376aa7adc92", null ],
    [ "lzma_block_buffer_bound", "block_8h.html#a58ff73e2572b529f48cc590bfffe5b4f", null ],
    [ "lzma_block_buffer_encode", "block_8h.html#af415fa5130ab64e8760e9c39e856fa54", null ],
    [ "lzma_block_uncomp_encode", "block_8h.html#a5a260f634ccd5f54fb98f570d8d92d8c", null ],
    [ "lzma_block_buffer_decode", "block_8h.html#a0c6eb869d91b08f68648b1aa7a32ee9f", null ]
];