var structlzma__block =
[
    [ "version", "structlzma__block.html#ac3936a5b0ec3f9b8f9c7ad68e7d149a5", null ],
    [ "header_size", "structlzma__block.html#a6689c4f7524b2c05772a2d6151138610", null ],
    [ "check", "structlzma__block.html#a80cd9d3025991db4a476ce7588f853e6", null ],
    [ "compressed_size", "structlzma__block.html#a8383d489c9ffea8af390669a105c74e5", null ],
    [ "uncompressed_size", "structlzma__block.html#a17362d38d1946dd16a9686557ec19a94", null ],
    [ "filters", "structlzma__block.html#a5900e517e6e0a473a3184074ae7defd1", null ],
    [ "raw_check", "structlzma__block.html#a25e9bf1bb1699017694b18ca24f965d2", null ],
    [ "ignore_check", "structlzma__block.html#a516ac9cc63bc1a4fadd9fbfc189a206b", null ]
];