var structlzma__index__iter =
[
    [ "flags", "structlzma__index__iter.html#a223a046bcf09077a6e720967682deeae", null ],
    [ "number", "structlzma__index__iter.html#a115a307dbc778a9de296376dc39c7b23", null ],
    [ "block_count", "structlzma__index__iter.html#abc6ee9be23e54f31aed07382c8caaf7c", null ],
    [ "compressed_offset", "structlzma__index__iter.html#a426705df8dde4b094a42f91ea20a46ac", null ],
    [ "uncompressed_offset", "structlzma__index__iter.html#abd374b748b4a42e122b90841709609bc", null ],
    [ "compressed_size", "structlzma__index__iter.html#a6e73b1f37e3fcf1e9491e4a53b2c52c7", null ],
    [ "uncompressed_size", "structlzma__index__iter.html#aafc48408ed40060a84ecd66bae5e1b23", null ],
    [ "padding", "structlzma__index__iter.html#a48cfc856f283fe00b0df37402e012818", null ],
    [ "number_in_file", "structlzma__index__iter.html#abe5333de53562189012d5ed084c0ef98", null ],
    [ "compressed_file_offset", "structlzma__index__iter.html#a26436e75d4c2b5dd8d1de24140d8003e", null ],
    [ "uncompressed_file_offset", "structlzma__index__iter.html#a2f3ecf341b5dc043e9673759b8ff47b9", null ],
    [ "number_in_stream", "structlzma__index__iter.html#a35a752d344ff5d35d2a858a20bd6e5e8", null ],
    [ "compressed_stream_offset", "structlzma__index__iter.html#a578bba553c43dc59a5e4032d4f6c89a3", null ],
    [ "uncompressed_stream_offset", "structlzma__index__iter.html#a0fc4959fab08e1a6a4902c728c735a99", null ],
    [ "unpadded_size", "structlzma__index__iter.html#a9f4e405b9884be08e3a35bc06e3e15df", null ],
    [ "total_size", "structlzma__index__iter.html#ae164ca3d7492dcf5883769c38baac30e", null ]
];