var structlzma__options__lzma =
[
    [ "dict_size", "structlzma__options__lzma.html#aeb3f86002405a1191af86def46fca5ad", null ],
    [ "preset_dict", "structlzma__options__lzma.html#a16a58c1ee3ec18c820d5cb03dde3739a", null ],
    [ "preset_dict_size", "structlzma__options__lzma.html#a655ad4cce9e4dac9cf2a5c8daaa629e0", null ],
    [ "lc", "structlzma__options__lzma.html#a95f6188e5b5f05c50ec463a315df3585", null ],
    [ "lp", "structlzma__options__lzma.html#a0fe9c54e808fce3090b6994d95fe41fe", null ],
    [ "pb", "structlzma__options__lzma.html#acae107b3d3e9d0d4fe16103be22f4408", null ],
    [ "mode", "structlzma__options__lzma.html#a1d711df9bda046fd3899abf21fa250d5", null ],
    [ "nice_len", "structlzma__options__lzma.html#a0352ea7f8b6a43b745a44f6cb4e2d263", null ],
    [ "mf", "structlzma__options__lzma.html#aa99612cd52259093007f33513882dcd0", null ],
    [ "depth", "structlzma__options__lzma.html#a4226f686e8c9f6288595fe23d0e15713", null ],
    [ "ext_flags", "structlzma__options__lzma.html#ade251d13ef46bcacb4e052b83693878c", null ],
    [ "ext_size_low", "structlzma__options__lzma.html#a971da8385dcebd01e60235afb3b717f9", null ],
    [ "ext_size_high", "structlzma__options__lzma.html#ae5b3c2375c43ddfacf093980385fb9e3", null ]
];