var structlzma__options__delta =
[
    [ "type", "structlzma__options__delta.html#af3f1ece7f8c472f4a794953b414c7cd7", null ],
    [ "dist", "structlzma__options__delta.html#a31b4b0b5a2462cb9433c2663b8a62790", null ]
];