var structlzma__stream__flags =
[
    [ "version", "structlzma__stream__flags.html#a61e9151869d5b77c868aaa4958e74d10", null ],
    [ "backward_size", "structlzma__stream__flags.html#aaa65ed7a55a098f829f04dba25d0f212", null ],
    [ "check", "structlzma__stream__flags.html#ab1052ea7047c8d67f127f33278166647", null ]
];