var stream__flags_8h =
[
    [ "lzma_stream_flags", "structlzma__stream__flags.html", "structlzma__stream__flags" ],
    [ "LZMA_STREAM_HEADER_SIZE", "stream__flags_8h.html#ada7e0a4f5e7146f547962cb9e9ef08ee", null ],
    [ "LZMA_BACKWARD_SIZE_MIN", "stream__flags_8h.html#ae8da8190f1396f66332073946bc45634", null ],
    [ "LZMA_BACKWARD_SIZE_MAX", "stream__flags_8h.html#a2e5e09010880f8caa6cd6539c7341239", null ],
    [ "lzma_stream_header_encode", "stream__flags_8h.html#a2ebb8d6dff23daeb3de398913b845eff", null ],
    [ "lzma_stream_footer_encode", "stream__flags_8h.html#a438249a75ea8da952a7474b92bfe7b7a", null ],
    [ "lzma_stream_header_decode", "stream__flags_8h.html#ae03198e464f0d296e601ff841e100805", null ],
    [ "lzma_stream_footer_decode", "stream__flags_8h.html#aa92a383f85753bb79ee23227fa68186c", null ],
    [ "lzma_stream_flags_compare", "stream__flags_8h.html#a3e25ca4205021302882a696283d45263", null ]
];