var version_8h =
[
    [ "LZMA_VERSION_MAJOR", "version_8h.html#aa0f450c9d3b0ff5f88b55888ed55701f", null ],
    [ "LZMA_VERSION_MINOR", "version_8h.html#af8fd295cf8aa349b0731423ad7a56134", null ],
    [ "LZMA_VERSION_PATCH", "version_8h.html#a8b550373cbff381f15d4308b852a3c2a", null ],
    [ "LZMA_VERSION_STABILITY", "version_8h.html#ae289abe5dcc203c7cda9f6a9a2f36b3a", null ],
    [ "LZMA_VERSION_COMMIT", "version_8h.html#a7fd6169ff15ac7f01f94970359a331ea", null ],
    [ "LZMA_VERSION", "version_8h.html#a156c47ff34aa0c2b726d0daf799f10a0", null ],
    [ "LZMA_VERSION_STRING", "version_8h.html#a57bb143c993c305a53e9aade831a546c", null ],
    [ "lzma_version_number", "version_8h.html#a72f929c9b9e8e730b790b3f8c80c3c80", null ],
    [ "lzma_version_string", "version_8h.html#a8998c1d8b4b5c2c1218bdfd58fdb1baa", null ]
];